==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/uk-UA/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Індивідуальні поля',
    'manage'                    => 'Керування',
    'field'		                => 'Поле',
    'about_fieldsets_title'		=> 'Про польові набори',
    'about_fieldsets_text'		=> 'Поля дозволяють створювати групи настроюваних полів, які часто повторно використовуються для конкретних типів моделі активів.',
    'custom_format'             => 'Користувацький формат регулярного виразу...',
    'encrypt_field'      	        => 'Шифрувати значення цього поля в базі даних',
    'encrypt_field_help'      => 'УВАГА: Шифрування поля робить його непридатним для пошуку.',
    'encrypted'      	        => 'Зашифровано',
    'fieldset'      	        => 'Набір полів',
    'qty_fields'      	      => 'Поля кількості',
    'fieldsets'      	        => 'Набір полів',
    'fieldset_name'           => 'Назва набору полів',
    'field_name'              => 'Назва поля',
    'field_values'            => 'Значення поля',
    'field_values_help'       => 'Додати опції для кожного рядка. Порожні лінії відмінні від першого рядку будуть проігноровані.',
    'field_element'           => 'Елемент форми',
    'field_element_short'     => 'Елемент',
    'field_format'            => 'Форматувати',
    'field_custom_format'     => 'Формат користувацьких регулярних виразів',
    'field_custom_format_help'     => 'Це поле дозволяє вам використовувати регулярний вираз для перевірки. Він має починатися з "regex:" - наприклад, щоб впевнитись, що користувацьке значення поля містить допустимий IMEI (15 числових цифр), ви будете використовувати <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Є обов\'язковим',
    'req'   		              => 'Обов.',
    'used_by_models'   		    => 'Використовується моделями',
    'order'   		            => 'Порядок',
    'create_fieldset'         => 'Новий набір полів',
    'update_fieldset'         => 'Оновити набір полів',
    'fieldset_does_not_exist'   => 'Набір полів :id не існує',
    'fieldset_updated'         => 'Набір полів оновлено',
    'create_fieldset_title' => 'Створити новий філдсет',
    'create_field'            => 'Нове власне поле',
    'create_field_title' => 'Створіть нове спеціальне поле',
    'value_encrypted'      	        => 'Значення цього поля зашифровано в базі даних. Тільки адміністратори зможуть переглядати значення розшифрованого',
    'show_in_email'     => 'Включити значення цього поля в листа для перевірки, які відправляються користувачу? Зашифровані поля не можуть бути включені в листи',
    'show_in_email_short' => 'Включити до email',
    'help_text' => 'Текст довідки',
    'help_text_description' => 'Це необов\'язковий текст, який буде відображатися під елементами форм під час редагування медіафайла для надання контексту в полі.',
    'about_custom_fields_title' => 'Про індивідуальні поля',
    'about_custom_fields_text' => 'Користувацькі поля дозволяють додавати довільні атрибути до активів.',
    'add_field_to_fieldset' => 'Додати поле в набір полів',
    'make_optional' => 'Необхідний - клік, щоб робити не обов\'язково',
    'make_required' => 'Необов\'язково - натисніть, щоб зробити необхідне',
    'reorder' => 'Змінити порядок',
    'db_field' => 'БД поле',
    'db_convert_warning' => 'УВАГА. Це поле міститься в таблиці спеціальних полів як <code>:db_column</code>, але має бути <code>:expected</code>.',
    'is_unique' => 'Ця величина повинна бути унікальною для всіх активів',
    'unique' => 'Унікальний',
    'display_in_user_view' => 'Дозволити відзначеному користувачеві переглядати ці значення у їх Перегляд призначені для додавання активів',
    'display_in_user_view_table' => 'Видимий користувачеві',
    'auto_add_to_fieldsets' => 'Автоматично додавати це до кожного нового поля',
    'add_to_preexisting_fieldsets' => 'Додати до будь-яких існуючих полей',
    'show_in_listview' => 'Показати у списку переглядів за замовчуванням. Авторизовані користувачі все ще зможуть показати/приховати через селектор стовпців',
    'show_in_listview_short' => 'Показати в списках',
    'show_in_requestable_list_short' => 'Показати в списку активів',
    'show_in_requestable_list' => 'Показувати значення в списку активів, які запитуються. Зашифровані поля не будуть показані',
    'encrypted_options' => 'Це поле зашифроване, так що деякі параметри відображення не будуть доступні.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/uk-UA/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Індивідуальні поля',
    'manage'                    => 'Керування',
    'field'		                => 'Поле',
    'about_fieldsets_title'		=> 'Про польові набори',
    'about_fieldsets_text'		=> 'Поля дозволяють створювати групи настроюваних полів, які часто повторно використовуються для конкретних типів моделі активів.',
    'custom_format'             => 'Користувацький формат регулярного виразу...',
    'encrypt_field'      	        => 'Шифрувати значення цього поля в базі даних',
    'encrypt_field_help'      => 'УВАГА: Шифрування поля робить його непридатним для пошуку.',
    'encrypted'      	        => 'Зашифровано',
    'fieldset'      	        => 'Набір полів',
    'qty_fields'      	      => 'Поля кількості',
    'fieldsets'      	        => 'Набір полів',
    'fieldset_name'           => 'Назва набору полів',
    'field_name'              => 'Назва поля',
    'field_values'            => 'Значення поля',
    'field_values_help'       => 'Додати опції для кожного рядка. Порожні лінії відмінні від першого рядку будуть проігноровані.',
    'field_element'           => 'Елемент форми',
    'field_element_short'     => 'Елемент',
    'field_format'            => 'Форматувати',
    'field_custom_format'     => 'Формат користувацьких регулярних виразів',
    'field_custom_format_help'     => 'Це поле дозволяє вам використовувати регулярний вираз для перевірки. Він має починатися з "regex:" - наприклад, щоб впевнитись, що користувацьке значення поля містить допустимий IMEI (15 числових цифр), ви будете використовувати <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Є обов\'язковим',
    'req'   		              => 'Обов.',
    'used_by_models'   		    => 'Використовується моделями',
    'order'   		            => 'Порядок',
    'create_fieldset'         => 'Новий набір полів',
    'update_fieldset'         => 'Оновити набір полів',
    'fieldset_does_not_exist'   => 'Набір полів :id не існує',
    'fieldset_updated'         => 'Набір полів оновлено',
    'create_fieldset_title' => 'Створити новий філдсет',
    'create_field'            => 'Нове власне поле',
    'create_field_title' => 'Створіть нове спеціальне поле',
    'value_encrypted'      	        => 'The value of this field is encrypted in the database. Only users with permission to view encrypted custom fields will be able to view the decrypted value',
    'show_in_email'     => 'Включити значення цього поля в листа для перевірки, які відправляються користувачу? Зашифровані поля не можуть бути включені в листи',
    'show_in_email_short' => 'Включити до email',
    'help_text' => 'Текст довідки',
    'help_text_description' => 'Це необов\'язковий текст, який буде відображатися під елементами форм під час редагування медіафайла для надання контексту в полі.',
    'about_custom_fields_title' => 'Про індивідуальні поля',
    'about_custom_fields_text' => 'Користувацькі поля дозволяють додавати довільні атрибути до активів.',
    'add_field_to_fieldset' => 'Додати поле в набір полів',
    'make_optional' => 'Необхідний - клік, щоб робити не обов\'язково',
    'make_required' => 'Необов\'язково - натисніть, щоб зробити необхідне',
    'reorder' => 'Змінити порядок',
    'db_field' => 'БД поле',
    'db_convert_warning' => 'УВАГА. Це поле міститься в таблиці спеціальних полів як <code>:db_column</code>, але має бути <code>:expected</code>.',
    'is_unique' => 'Ця величина повинна бути унікальною для всіх активів',
    'unique' => 'Унікальний',
    'display_in_user_view' => 'Дозволити відзначеному користувачеві переглядати ці значення у їх Перегляд призначені для додавання активів',
    'display_in_user_view_table' => 'Видимий користувачеві',
    'auto_add_to_fieldsets' => 'Автоматично додавати це до кожного нового поля',
    'add_to_preexisting_fieldsets' => 'Додати до будь-яких існуючих полей',
    'show_in_listview' => 'Показати у списку переглядів за замовчуванням. Авторизовані користувачі все ще зможуть показати/приховати через селектор стовпців',
    'show_in_listview_short' => 'Показати в списках',
    'show_in_requestable_list_short' => 'Показати в списку активів',
    'show_in_requestable_list' => 'Показувати значення в списку активів, які запитуються. Зашифровані поля не будуть показані',
    'encrypted_options' => 'Це поле зашифроване, так що деякі параметри відображення не будуть доступні.',
    'display_checkin' => 'Відображати в формах перевірки',
    'display_checkout' => 'Відображати в формах перевірки',
    'display_audit' => 'Відображати в формах перевірки',
    'types' => [
        'text' => 'Text Box',
        'listbox' => 'List Box',
        'textarea' => 'Textarea (multi-line)',
        'checkbox' => 'Checkbox',
        'radio' => 'Radio Buttons',
    ],
];
